@@ -47,9 +47,7 @@ def get_env_var(name: str) -> Optional[str]:
                 current_path = current_path.strip().replace("\r", "").replace("\n", "")
 
     elif completed_process.returncode == 1:
-        _print("environment variable PATH does not exist.")
-        _print(_try_decode(completed_process.stderr))
-        raise OSError("environment variable PATH does not exist.")
+        return None
     return current_path
 
 
@@ -74,6 +72,16 @@ def set_env_var_cmd(name: str, value: str) -> None:
     assert value in get_env_var(name), f"Failed to set {name}={value}"  # type: ignore
 
 
+def unset_env_var_cmd(name: str) -> None:
+    completed_proc: subprocess.CompletedProcess = _command(
+        ["reg", "delete", "HKCU\\Environment", "/v", name, "/f"]
+    )
+    if completed_proc.returncode != 0:
+        _print(f"Error happened while unsetting {name}")
+        _print(_try_decode(completed_proc.stdout))
+    assert get_env_var(name) is None, f"Failed to unset {name}"  # type: ignore
+
+
 def get_reg_env_path() -> str:
     path = get_env_var("PATH")
     assert path is not None, "PATH was None, which was unexpected."
@@ -135,6 +143,32 @@ def set_env_var(var_name: str, var_value: str, verbose=True):
     os.environ[var_name] = var_value
 
 
+def unset_env_var(var_name: str, verbose=True):
+    var_name = str(var_name)
+    if verbose:
+        print(f"$$$ Unsetting {var_name}")
+    if var_name == "PATH":
+        raise ValueError("Cannot unset PATH")
+    unset_env_var_cmd(var_name)
+    os.environ.pop(var_name)
+
+
+def remove_env_path(path_to_remove: str, verbose=False):
+    # convert / to \\ for Windows
+    path_to_remove = path_to_remove.replace("/", "\\")
+    path_str = get_reg_env_path()
+    if path_to_remove not in path_str:
+        if verbose:
+            print(f"{path_to_remove} not in PATH")
+        return
+    paths = parse_paths(path_str)
+    paths = [path for path in paths if path != path_to_remove]
+    sep = os.path.pathsep
+    new_path_str = sep.join(paths)
+    os.environ["PATH"] = new_path_str
+    set_env_var_cmd("PATH", new_path_str)
+
+
 def main():
     set_env_var_cmd("FOO", "BAR")
     print(get_env_var("FOO"))
